@@ -1075,6 +1075,8 @@ static void canvas_dsp(t_canvas *x, t_signal **sp)
     canvas_dodsp(x, 0, sp);
 }
 
+int canvas_dspstate;
+
     /* this routine starts DSP for all root canvases. */
 static void canvas_start_dsp(void)
 {
@@ -1086,7 +1088,7 @@ static void canvas_start_dsp(void)
     for (x = pd_getcanvaslist(); x; x = x->gl_next)
         canvas_dodsp(x, 1, 0);
     
-    pd_this->pd_dspstate = 1;
+    canvas_dspstate = pd_this->pd_dspstate = 1;
 }
 
 static void canvas_stop_dsp(void)
@@ -1095,7 +1097,7 @@ static void canvas_stop_dsp(void)
     {
         ugen_stop();
         sys_gui("pdtk_pd_dsp OFF\n");
-        pd_this->pd_dspstate = 0;
+        canvas_dspstate = pd_this->pd_dspstate = 0;
     }
 }
 
