@@ -200,6 +200,18 @@ t_binbuf *pointertobinbuf(t_pd *x, t_gpointer *gp, t_symbol *s,
     return (vec[onset].w_binbuf);
 }
 
+    /* templates are named using the name-bashing by which canvases bind
+    thenselves, with a leading "pd-".  LATER see if we can have templates
+    occupy their real names.  Meanwhile, if a template has an empty name
+    or is named "-" (as when passed as a "-" argument to "get", etc.), just
+    return &s_; objects should check for this and allow it as a wild
+    card when appropriate. */
+static t_symbol *template_getbindsym(t_symbol *s)
+{
+    if (!*s->s_name || !strcmp(s->s_name, "-"))
+        return (&s_);
+    else return (canvas_makebindsym(s));
+}
 
 /* ---------------------- pointers ----------------------------- */
 
@@ -232,7 +244,7 @@ static void *ptrobj_new(t_symbol *classname, int argc, t_atom *argv)
     for (; n--; to++)
     {
         to->to_outlet = outlet_new(&x->x_obj, &s_pointer);
-        to->to_type = canvas_makebindsym(atom_getsymbol(argv++));
+        to->to_type = template_getbindsym(atom_getsymbol(argv++));
     }
     x->x_otherout = outlet_new(&x->x_obj, &s_pointer);
     x->x_bangout = outlet_new(&x->x_obj, &s_bang);
@@ -459,16 +471,24 @@ typedef struct _get
 static void *get_new(t_symbol *why, int argc, t_atom *argv)
 {
     t_get *x = (t_get *)pd_new(get_class);
-    int i;
+    int varcount, i;
+    t_atom at, *varvec;
     t_getvariable *sp;
-    x->x_templatesym = canvas_makebindsym(atom_getsymbolarg(0, argc, argv));
-    if (argc) argc--, argv++;
-    x->x_variables
-        = (t_getvariable *)getbytes(argc * sizeof (*x->x_variables));
-    x->x_nout = argc;
-    for (i = 0, sp = x->x_variables; i < argc; i++, sp++)
+
+    x->x_templatesym = template_getbindsym(atom_getsymbolarg(0, argc, argv));
+    if (argc < 2)
     {
-        sp->gv_sym = atom_getsymbolarg(i, argc, argv);
+        varcount = 1;
+        varvec = &at;
+        SETSYMBOL(&at, &s_);
+    }
+    else varcount = argc - 1, varvec = argv + 1;
+    x->x_variables
+        = (t_getvariable *)getbytes(varcount * sizeof (*x->x_variables));
+    x->x_nout = varcount;
+    for (i = 0, sp = x->x_variables; i < varcount; i++, sp++)
+    {
+        sp->gv_sym = atom_getsymbolarg(i, varcount, varvec);
         sp->gv_outlet = outlet_new(&x->x_obj, 0);
             /* LATER connect with the template and set the outlet's type
             correctly.  We can't yet guarantee that the template is there
@@ -477,24 +497,46 @@ static void *get_new(t_symbol *why, int argc, t_atom *argv)
     return (x);
 }
 
+static void get_set(t_get *x, t_symbol *templatesym, t_symbol *field)
+{
+    if (x->x_nout != 1)
+        pd_error(x, "get: cannot set multiple fields.");
+    else
+    {
+        x->x_templatesym = template_getbindsym(templatesym); 
+        x->x_variables->gv_sym = field;
+    }
+}
+
 static void get_pointer(t_get *x, t_gpointer *gp)
 {
     int nitems = x->x_nout, i;
-    t_symbol *templatesym = x->x_templatesym;
-    t_template *template = template_findbyname(templatesym);
+    t_symbol *templatesym;
+    t_template *template;
     t_gstub *gs = gp->gp_stub;
     t_word *vec; 
     t_getvariable *vp;
-    if (!template)
-    {
-        pd_error(x, "get: couldn't find template %s", templatesym->s_name);
-        return;
-    }
+
     if (!gpointer_check(gp, 0))
     {
         pd_error(x, "get: stale or empty pointer");
         return;
     }
+    if (*x->x_templatesym->s_name)
+    {
+        if ((templatesym = x->x_templatesym) != gpointer_gettemplatesym(gp))
+        {
+            pd_error(x, "get %s: got wrong template (%s)",
+                templatesym->s_name, gpointer_gettemplatesym(gp)->s_name);
+            return;
+        } 
+    }
+    else templatesym = gpointer_gettemplatesym(gp);
+    if (!(template = template_findbyname(templatesym)))
+    {
+        pd_error(x, "get: couldn't find template %s", templatesym->s_name);
+        return;
+    }
     if (gs->gs_which == GP_ARRAY) vec = gp->gp_un.gp_w;
     else vec = gp->gp_un.gp_scalar->sc_vec;
     for (i = nitems - 1, vp = x->x_variables + i; i >= 0; i--, vp--)
@@ -527,6 +569,8 @@ static void get_setup(void)
     get_class = class_new(gensym("get"), (t_newmethod)get_new,
         (t_method)get_free, sizeof(t_get), 0, A_GIMME, 0);
     class_addpointer(get_class, get_pointer); 
+    class_addmethod(get_class, (t_method)get_set, gensym("set"),
+        A_SYMBOL, A_SYMBOL, 0); 
 }
 
 /* ---------------------- set ----------------------------- */
@@ -552,8 +596,9 @@ typedef struct _set
 static void *set_new(t_symbol *why, int argc, t_atom *argv)
 {
     t_set *x = (t_set *)pd_new(set_class);
-    int i;
+    int i, varcount;
     t_setvariable *sp;
+    t_atom at, *varvec;
     if (argc && (argv[0].a_type == A_SYMBOL) &&
         !strcmp(argv[0].a_w.w_symbol->s_name, "-symbol"))
     {
@@ -562,25 +607,28 @@ static void *set_new(t_symbol *why, int argc, t_atom *argv)
         argv++;
     }
     else x->x_issymbol = 0;
-    x->x_templatesym = canvas_makebindsym(atom_getsymbolarg(0, argc, argv));
-    if (argc) argc--, argv++;
-    x->x_variables
-        = (t_setvariable *)getbytes(argc * sizeof (*x->x_variables));
-    x->x_nin = argc;
-    if (argc)
+    x->x_templatesym = template_getbindsym(atom_getsymbolarg(0, argc, argv));
+    if (argc < 2)
     {
-        for (i = 0, sp = x->x_variables; i < argc; i++, sp++)
+        varcount = 1;
+        varvec = &at;
+        SETSYMBOL(&at, &s_);
+    }
+    else varcount = argc - 1, varvec = argv + 1;
+    x->x_variables
+        = (t_setvariable *)getbytes(varcount * sizeof (*x->x_variables));
+    x->x_nin = varcount;
+    for (i = 0, sp = x->x_variables; i < varcount; i++, sp++)
+    {
+        sp->gv_sym = atom_getsymbolarg(i, varcount, varvec);
+        if (x->x_issymbol)
+            sp->gv_w.w_symbol = &s_;
+        else sp->gv_w.w_float = 0;
+        if (i)
         {
-            sp->gv_sym = atom_getsymbolarg(i, argc, argv);
             if (x->x_issymbol)
-                sp->gv_w.w_symbol = &s_;
-            else sp->gv_w.w_float = 0;
-            if (i)
-            {
-                if (x->x_issymbol)
-                    symbolinlet_new(&x->x_obj, &sp->gv_w.w_symbol);
-                else floatinlet_new(&x->x_obj, &sp->gv_w.w_float);
-            }
+                symbolinlet_new(&x->x_obj, &sp->gv_w.w_symbol);
+            else floatinlet_new(&x->x_obj, &sp->gv_w.w_float);
         }
     }
     pointerinlet_new(&x->x_obj, &x->x_gp);
@@ -588,29 +636,48 @@ static void *set_new(t_symbol *why, int argc, t_atom *argv)
     return (x);
 }
 
+static void set_set(t_set *x, t_symbol *templatesym, t_symbol *field)
+{
+    if (x->x_nin != 1)
+        pd_error(x, "set: cannot set multiple fields.");
+    else
+    {
+       x->x_templatesym = template_getbindsym(templatesym); 
+       x->x_variables->gv_sym = field;
+       if (x->x_issymbol)
+           x->x_variables->gv_w.w_symbol = &s_;
+       else
+           x->x_variables->gv_w.w_float = 0;
+    }
+}
+
 static void set_bang(t_set *x)
 {
     int nitems = x->x_nin, i;
-    t_symbol *templatesym = x->x_templatesym;
-    t_template *template = template_findbyname(templatesym);
+    t_symbol *templatesym;
+    t_template *template;
     t_setvariable *vp;
     t_gpointer *gp = &x->x_gp;
     t_gstub *gs = gp->gp_stub;
     t_word *vec;
-    if (!template)
-    {
-        pd_error(x, "set: couldn't find template %s", templatesym->s_name);
-        return;
-    }
     if (!gpointer_check(gp, 0))
     {
         pd_error(x, "set: empty pointer");
         return;
     }
-    if (gpointer_gettemplatesym(gp) != x->x_templatesym)
+    if (*x->x_templatesym->s_name)
     {
-        pd_error(x, "set %s: got wrong template (%s)",
-            x->x_templatesym->s_name, gpointer_gettemplatesym(gp)->s_name);
+        if ((templatesym = x->x_templatesym) != gpointer_gettemplatesym(gp))
+        {
+            pd_error(x, "set %s: got wrong template (%s)",
+                templatesym->s_name, gpointer_gettemplatesym(gp)->s_name);
+            return;
+        } 
+    }
+    else templatesym = gpointer_gettemplatesym(gp);
+    if (!(template = template_findbyname(templatesym)))
+    {
+        pd_error(x, "set: couldn't find template %s", templatesym->s_name);
         return;
     }
     if (!nitems)
@@ -668,6 +735,8 @@ static void set_setup(void)
     class_addfloat(set_class, set_float); 
     class_addsymbol(set_class, set_symbol); 
     class_addbang(set_class, set_bang); 
+    class_addmethod(set_class, (t_method)set_set, gensym("set"),
+        A_SYMBOL, A_SYMBOL, 0); 
 }
 
 /* ---------------------- elem ----------------------------- */
@@ -686,7 +755,7 @@ typedef struct _elem
 static void *elem_new(t_symbol *templatesym, t_symbol *fieldsym)
 {
     t_elem *x = (t_elem *)pd_new(elem_class);
-    x->x_templatesym = canvas_makebindsym(templatesym);
+    x->x_templatesym = template_getbindsym(templatesym);
     x->x_fieldsym = fieldsym;
     gpointer_init(&x->x_gp);
     gpointer_init(&x->x_gparent);
@@ -695,12 +764,17 @@ static void *elem_new(t_symbol *templatesym, t_symbol *fieldsym)
     return (x);
 }
 
+static void elem_set(t_elem *x, t_symbol *templatesym, t_symbol *fieldsym)
+{
+    x->x_templatesym = template_getbindsym(templatesym);
+    x->x_fieldsym = fieldsym;
+}
+
 static void elem_float(t_elem *x, t_float f)
 {
     int indx = f, nitems, onset;
-    t_symbol *templatesym = x->x_templatesym, *fieldsym = x->x_fieldsym,
-        *elemtemplatesym;
-    t_template *template = template_findbyname(templatesym);
+    t_symbol *templatesym, *fieldsym = x->x_fieldsym, *elemtemplatesym;
+    t_template *template;
     t_template *elemtemplate;
     t_gpointer *gparent = &x->x_gparent;
     t_word *w;
@@ -712,10 +786,20 @@ static void elem_float(t_elem *x, t_float f)
         pd_error(x, "element: empty pointer");
         return;
     }
-    if (gpointer_gettemplatesym(gparent) != x->x_templatesym)
+    if (*x->x_templatesym->s_name)
     {
-        pd_error(x, "element %s: got wrong template (%s)",
-            x->x_templatesym->s_name, gpointer_gettemplatesym(gparent)->s_name);
+        if ((templatesym = x->x_templatesym) !=
+            gpointer_gettemplatesym(gparent))
+        {
+            pd_error(x, "elem %s: got wrong template (%s)",
+                templatesym->s_name, gpointer_gettemplatesym(gparent)->s_name);
+            return;
+        } 
+    }
+    else templatesym = gpointer_gettemplatesym(gparent);
+    if (!(template = template_findbyname(templatesym)))
+    {
+        pd_error(x, "elem: couldn't find template %s", templatesym->s_name);
         return;
     }
     if (gparent->gp_stub->gs_which == GP_ARRAY) w = gparent->gp_un.gp_w;
@@ -767,6 +851,8 @@ static void elem_setup(void)
     elem_class = class_new(gensym("element"), (t_newmethod)elem_new,
         (t_method)elem_free, sizeof(t_elem), 0, A_DEFSYM, A_DEFSYM, 0);
     class_addfloat(elem_class, elem_float); 
+    class_addmethod(elem_class, (t_method)elem_set, gensym("set"),
+        A_SYMBOL, A_SYMBOL, 0); 
 }
 
 /* ---------------------- getsize ----------------------------- */
@@ -783,25 +869,46 @@ typedef struct _getsize
 static void *getsize_new(t_symbol *templatesym, t_symbol *fieldsym)
 {
     t_getsize *x = (t_getsize *)pd_new(getsize_class);
-    x->x_templatesym = canvas_makebindsym(templatesym);
+    x->x_templatesym = template_getbindsym(templatesym);
     x->x_fieldsym = fieldsym;
     outlet_new(&x->x_obj, &s_float);
     return (x);
 }
 
+static void getsize_set(t_getsize *x, t_symbol *templatesym, t_symbol *fieldsym)
+{
+    x->x_templatesym = template_getbindsym(templatesym);
+    x->x_fieldsym = fieldsym;
+}
+
 static void getsize_pointer(t_getsize *x, t_gpointer *gp)
 {
     int nitems, onset, type;
-    t_symbol *templatesym = x->x_templatesym, *fieldsym = x->x_fieldsym,
-        *elemtemplatesym;
-    t_template *template = template_findbyname(templatesym);
+    t_symbol *templatesym, *fieldsym = x->x_fieldsym, *elemtemplatesym;
+    t_template *template;
     t_word *w;
     t_array *array;
     int elemsize;
     t_gstub *gs = gp->gp_stub;
-    if (!template)
+    if (!gpointer_check(gp, 0))
     {
-        pd_error(x, "getsize: couldn't find template %s", templatesym->s_name);
+        pd_error(x, "getsize: stale or empty pointer");
+        return;
+    }
+    if (*x->x_templatesym->s_name)
+    {
+        if ((templatesym = x->x_templatesym) !=
+            gpointer_gettemplatesym(gp))
+        {
+            pd_error(x, "elem %s: got wrong template (%s)",
+                templatesym->s_name, gpointer_gettemplatesym(gp)->s_name);
+            return;
+        } 
+    }
+    else templatesym = gpointer_gettemplatesym(gp);
+    if (!(template = template_findbyname(templatesym)))
+    {
+        pd_error(x, "elem: couldn't find template %s", templatesym->s_name);
         return;
     }
     if (!template_find_field(template, fieldsym,
@@ -815,17 +922,6 @@ static void getsize_pointer(t_getsize *x, t_gpointer *gp)
         pd_error(x, "getsize: field %s not of type array", fieldsym->s_name);
         return;
     }
-    if (!gpointer_check(gp, 0))
-    {
-        pd_error(x, "get: stale or empty pointer");
-        return;
-    }
-    if (gpointer_gettemplatesym(gp) != x->x_templatesym)
-    {
-        pd_error(x, "getsize %s: got wrong template (%s)",
-            x->x_templatesym->s_name, gpointer_gettemplatesym(gp)->s_name);
-        return;
-    }
     if (gs->gs_which == GP_ARRAY) w = gp->gp_un.gp_w;
     else w = gp->gp_un.gp_scalar->sc_vec;
     
@@ -838,6 +934,8 @@ static void getsize_setup(void)
     getsize_class = class_new(gensym("getsize"), (t_newmethod)getsize_new, 0,
         sizeof(t_getsize), 0, A_DEFSYM, A_DEFSYM, 0);
     class_addpointer(getsize_class, getsize_pointer); 
+    class_addmethod(getsize_class, (t_method)getsize_set, gensym("set"),
+        A_SYMBOL, A_SYMBOL, 0); 
 }
 
 /* ---------------------- setsize ----------------------------- */
@@ -856,7 +954,7 @@ static void *setsize_new(t_symbol *templatesym, t_symbol *fieldsym,
     t_floatarg newsize)
 {
     t_setsize *x = (t_setsize *)pd_new(setsize_class);
-    x->x_templatesym = canvas_makebindsym(templatesym);
+    x->x_templatesym = template_getbindsym(templatesym);
     x->x_fieldsym = fieldsym;
     gpointer_init(&x->x_gp);
     
@@ -864,12 +962,17 @@ static void *setsize_new(t_symbol *templatesym, t_symbol *fieldsym,
     return (x);
 }
 
+static void setsize_set(t_setsize *x, t_symbol *templatesym, t_symbol *fieldsym)
+{
+    x->x_templatesym = template_getbindsym(templatesym);
+    x->x_fieldsym = fieldsym;
+}
+
 static void setsize_float(t_setsize *x, t_float f)
 {
     int nitems, onset, type;
-    t_symbol *templatesym = x->x_templatesym, *fieldsym = x->x_fieldsym,
-        *elemtemplatesym;
-    t_template *template = template_findbyname(templatesym);
+    t_symbol *templatesym, *fieldsym = x->x_fieldsym, *elemtemplatesym;
+    t_template *template;
     t_template *elemtemplate;
     t_word *w;
     t_atom at;
@@ -883,21 +986,23 @@ static void setsize_float(t_setsize *x, t_float f)
         pd_error(x, "setsize: empty pointer");
         return;
     }
-    if (gpointer_gettemplatesym(&x->x_gp) != x->x_templatesym)
+    if (*x->x_templatesym->s_name)
     {
-        pd_error(x, "setsize %s: got wrong template (%s)",
-            x->x_templatesym->s_name,
-                gpointer_gettemplatesym(&x->x_gp)->s_name);
+        if ((templatesym = x->x_templatesym) !=
+            gpointer_gettemplatesym(gp))
+        {
+            pd_error(x, "elem %s: got wrong template (%s)",
+                templatesym->s_name, gpointer_gettemplatesym(gp)->s_name);
+            return;
+        } 
+    }
+    else templatesym = gpointer_gettemplatesym(gp);
+    if (!(template = template_findbyname(templatesym)))
+    {
+        pd_error(x, "elem: couldn't find template %s", templatesym->s_name);
         return;
     }
-    if (gs->gs_which == GP_ARRAY) w = gp->gp_un.gp_w;
-    else w = gp->gp_un.gp_scalar->sc_vec;
 
-    if (!template)
-    {
-        pd_error(x,"setsize: couldn't find template %s", templatesym->s_name);
-        return;
-    }
     if (!template_find_field(template, fieldsym,
         &onset, &type, &elemtemplatesym))
     {
@@ -909,6 +1014,8 @@ static void setsize_float(t_setsize *x, t_float f)
         pd_error(x,"setsize: field %s not of type array", fieldsym->s_name);
         return;
     }
+    if (gs->gs_which == GP_ARRAY) w = gp->gp_un.gp_w;
+    else w = gp->gp_un.gp_scalar->sc_vec;
 
     if (!(elemtemplate = template_findbyname(elemtemplatesym)))
     {
@@ -947,21 +1054,27 @@ static void setsize_float(t_setsize *x, t_float f)
             gobj_vis((t_gobj *)(owner_array->a_gp.gp_un.gp_scalar),
                 owner_array->a_gp.gp_stub->gs_un.gs_glist, 0);  
     }
-        /* now do the resizing and, if growing, initialize new scalars */
+        /* if shrinking, free the scalars that will disappear */
+    if (newsize < nitems)
+    {
+        char *elem;
+        int count;       
+        for (elem = ((char *)array->a_vec) + newsize * elemsize,
+            count = nitems - newsize; count--; elem += elemsize)
+                word_free((t_word *)elem, elemtemplate);
+    }
+        /* resize the array  */
     array->a_vec = (char *)resizebytes(array->a_vec,
         elemsize * nitems, elemsize * newsize);
     array->a_n = newsize;
+        /* if growing, initialize new scalars */
     if (newsize > nitems)
     {
-        char *newelem = ((char *)array->a_vec) + nitems * elemsize;
-        int i = 0, nnew = newsize - nitems;
-        
-        while (nnew--)
-        {
-            word_init((t_word *)newelem, elemtemplate, gp);
-            newelem += elemsize;
-            /* post("new %lx %lx, ntypes %d", newelem, *(int *)newelem, ntypes); */
-        }
+        char *elem;
+        int count;       
+        for (elem = ((char *)array->a_vec) + nitems * elemsize,
+            count = newsize - nitems; count--; elem += elemsize)
+                word_init((t_word *)elem, elemtemplate, gp);
     }
 
     /* redraw again. */
@@ -981,7 +1094,6 @@ static void setsize_float(t_setsize *x, t_float f)
     }
 }
 
-
 static void setsize_free(t_setsize *x)
 {
     gpointer_unset(&x->x_gp);
@@ -993,6 +1105,9 @@ static void setsize_setup(void)
         (t_method)setsize_free, sizeof(t_setsize), 0,
         A_DEFSYM, A_DEFSYM, A_DEFFLOAT, 0);
     class_addfloat(setsize_class, setsize_float);
+    class_addmethod(setsize_class, (t_method)setsize_set, gensym("set"),
+        A_SYMBOL, A_SYMBOL, 0); 
+
 }
 
 /* ---------------------- append ----------------------------- */
@@ -1017,21 +1132,26 @@ typedef struct _append
 static void *append_new(t_symbol *why, int argc, t_atom *argv)
 {
     t_append *x = (t_append *)pd_new(append_class);
-    int i;
+    int varcount, i;
+    t_atom at, *varvec;
     t_appendvariable *sp;
-    x->x_templatesym = canvas_makebindsym(atom_getsymbolarg(0, argc, argv));
-    if (argc) argc--, argv++;
-    x->x_variables
-        = (t_appendvariable *)getbytes(argc * sizeof (*x->x_variables));
-    x->x_nin = argc;
-    if (argc)
+
+    x->x_templatesym = template_getbindsym(atom_getsymbolarg(0, argc, argv));
+    if (argc < 2)
     {
-        for (i = 0, sp = x->x_variables; i < argc; i++, sp++)
-        {
-            sp->gv_sym = atom_getsymbolarg(i, argc, argv);
-            sp->gv_f = 0;
-            if (i) floatinlet_new(&x->x_obj, &sp->gv_f);
-        }
+        varcount = 1;
+        varvec = &at;
+        SETSYMBOL(&at, &s_);
+    }
+    else varcount = argc - 1, varvec = argv + 1;
+    x->x_variables
+        = (t_appendvariable *)getbytes(varcount * sizeof (*x->x_variables));
+    x->x_nin = varcount;
+    for (i = 0, sp = x->x_variables; i < varcount; i++, sp++)
+    {
+        sp->gv_sym = atom_getsymbolarg(i, varcount, varvec);
+        sp->gv_f = 0;
+        if (i) floatinlet_new(&x->x_obj, &sp->gv_f);
     }
     pointerinlet_new(&x->x_obj, &x->x_gp);
     outlet_new(&x->x_obj, &s_pointer);
@@ -1039,17 +1159,36 @@ static void *append_new(t_symbol *why, int argc, t_atom *argv)
     return (x);
 }
 
+static void append_set(t_append *x, t_symbol *templatesym, t_symbol *field)
+{
+    if (x->x_nin != 1)
+        pd_error(x, "set: cannot set multiple fields.");
+    else
+    {
+       x->x_templatesym = template_getbindsym(templatesym); 
+       x->x_variables->gv_sym = field;
+       x->x_variables->gv_f = 0;
+    }
+}
+
 static void append_float(t_append *x, t_float f)
 {
     int nitems = x->x_nin, i;
     t_symbol *templatesym = x->x_templatesym;
-    t_template *template = template_findbyname(templatesym);
+    t_template *template;
     t_appendvariable *vp;
     t_gpointer *gp = &x->x_gp;
     t_gstub *gs = gp->gp_stub;
     t_word *vec;
     t_scalar *sc, *oldsc;
     t_glist *glist;
+    
+    if (!templatesym->s_name)
+    {
+        pd_error(x, "append: no template supplied");
+        return;
+    }
+    template = template_findbyname(templatesym);
     if (!template)
     {
         pd_error(x, "append: couldn't find template %s", templatesym->s_name);
@@ -1119,6 +1258,8 @@ static void append_setup(void)
     append_class = class_new(gensym("append"), (t_newmethod)append_new,
         (t_method)append_free, sizeof(t_append), 0, A_GIMME, 0);
     class_addfloat(append_class, append_float); 
+    class_addmethod(append_class, (t_method)append_set, gensym("set"),
+        A_SYMBOL, A_SYMBOL, 0); 
 }
 
 /* ----------------- setup function ------------------- */
