@@ -287,7 +287,7 @@ void sys_set_priority(int higher)
 #ifdef USEAPI_JACK    
     p3 = (higher ? p1 + 7 : p1 + 5);
 #else
-    p3 = (higher ? p2 - 1 : p2 - 3);
+    p3 = (higher ? p2 - 5 : p2 - 7);
 #endif
     par.sched_priority = p3;
     if (sched_setscheduler(0,SCHED_FIFO,&par) < 0)
@@ -793,14 +793,15 @@ void sys_queuegui(void *client, t_glist *glist, t_guicallbackfn f)
 void sys_unqueuegui(void *client)
 {
     t_guiqueue *gq, *gq2;
+    while (sys_guiqueuehead && sys_guiqueuehead->gq_client == client)
+    {
+        gq = sys_guiqueuehead;
+        sys_guiqueuehead = sys_guiqueuehead->gq_next;
+        t_freebytes(gq, sizeof(*gq));
+    }
     if (!sys_guiqueuehead)
         return;
-    if (sys_guiqueuehead->gq_client == client)
-    {
-        t_freebytes(sys_guiqueuehead, sizeof(*sys_guiqueuehead));
-        sys_guiqueuehead = 0;
-    }
-    else for (gq = sys_guiqueuehead; gq2 = gq->gq_next; gq = gq2)
+    for (gq = sys_guiqueuehead; gq2 = gq->gq_next; gq = gq2)
         if (gq2->gq_client == client)
     {
         gq->gq_next = gq2->gq_next;
